aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/core/SkImageFilter.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/core/SkImageFilter.h')
-rw-r--r--include/core/SkImageFilter.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/core/SkImageFilter.h b/include/core/SkImageFilter.h
index d9b0fb04ab..60000798e4 100644
--- a/include/core/SkImageFilter.h
+++ b/include/core/SkImageFilter.h
@@ -434,13 +434,13 @@ private:
};
/**
* Helper to unflatten the common data, and return NULL if we fail.
*/
#define SK_IMAGEFILTER_UNFLATTEN_COMMON(localVar, expectedCount) \
Common localVar; \
do { \
if (!localVar.unflatten(buffer, expectedCount)) { \
- return NULL; \
+ return nullptr; \
} \
} while (0)
@@ -434,13 +434,13 @@ private:
};
/**
- * Helper to unflatten the common data, and return NULL if we fail.
+ * Helper to unflatten the common data, and return nullptr if we fail.
*/
#define SK_IMAGEFILTER_UNFLATTEN_COMMON(localVar, expectedCount) \